@@ -1,4 +1,6 @@
 /*
+ * Copyright (C) 2018-2021 Matthieu Gautier <mgautier@kymeria.fr>
+ * Copyright (C) 2020 Veloman Yankan
  * Copyright (C) 2006 Tommi Maekitalo
  *
  * This program is free software; you can redistribute it and/or
@@ -42,7 +44,7 @@ namespace zim
       cluster_index_t clusterNumber;  // only used when redirect is false
       blob_index_t blobNumber;    // only used when redirect is false
 
-      article_index_t redirectIndex;  // only used when redirect is true
+      entry_index_t redirectIndex;  // only used when redirect is true
 
       char ns;
       std::string title;
@@ -64,8 +66,6 @@ namespace zim
           ns('\0')
       {}
 
-      explicit Dirent(const Buffer& buffer);
-
       bool isRedirect() const                 { return mimeType == redirectMimeType; }
       bool isLinktarget() const               { return mimeType == linktargetMimeType; }
       bool isDeleted() const                  { return mimeType == deletedMimeType; }
@@ -78,7 +78,7 @@ namespace zim
       cluster_index_t getClusterNumber() const      { return isRedirect() ? cluster_index_t(0) : clusterNumber; }
       blob_index_t  getBlobNumber() const         { return isRedirect() ? blob_index_t(0) : blobNumber; }
 
-      article_index_t getRedirectIndex() const      { return isRedirect() ? redirectIndex : article_index_t(0); }
+      entry_index_t getRedirectIndex() const      { return isRedirect() ? redirectIndex : entry_index_t(0); }
 
       char getNamespace() const               { return ns; }
       const std::string& getTitle() const     { return title.empty() ? url : title; }
@@ -110,15 +110,14 @@ namespace zim
         parameter = parameter_;
       }
 
-      void setRedirect(article_index_t idx)
+      void setRedirect(entry_index_t idx)
       {
         redirectIndex = idx;
         mimeType = redirectMimeType;
       }
 
-      void setArticle(uint16_t mimeType_, cluster_index_t clusterNumber_, blob_index_t blobNumber_)
+      void setItem(uint16_t mimeType_, cluster_index_t clusterNumber_, blob_index_t blobNumber_)
       {
-        ASSERT(mimeType, ==, 0);
         mimeType = mimeType_;
         clusterNumber = clusterNumber_;
         blobNumber = blobNumber_;
