@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2017 Matthieu Gautier <mgautier@kymeria.fr>
+ * Copyright (C) 2017-2021 Matthieu Gautier <mgautier@kymeria.fr>
+ * Copyright (C) 2020 Veloman Yunkan
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,15 +22,19 @@
 #define ZIM_FILE_READER_H_
 
 #include "reader.h"
+#include "fs.h"
 
 namespace zim {
 
 class FileCompound;
 
 class FileReader : public Reader {
-  public:
-    FileReader(std::shared_ptr<const FileCompound> source);
-    ~FileReader() {};
+  public: // types
+    typedef std::shared_ptr<const DEFAULTFS::FD> FileHandle;
+
+  public: // functions
+    explicit FileReader(FileHandle fh, offset_t offset, zsize_t size);
+    ~FileReader() = default;
 
     zsize_t size() const { return _size; };
     offset_t offset() const { return _offset; };
@@ -38,11 +43,33 @@ class FileReader : public Reader {
     void read(char* dest, offset_t offset, zsize_t size) const;
     const Buffer get_buffer(offset_t offset, zsize_t size) const;
 
-    std::unique_ptr<const Reader> sub_reader(offset_t offest, zsize_t size) const;
+    std::unique_ptr<const Reader> sub_reader(offset_t offset, zsize_t size) const;
+
+  private: // data
+    // The file handle is stored via a shared pointer so that it can be shared
+    // by a sub_reader (otherwise the file handle would be invalidated by
+    // FD destructor when the sub-reader is destroyed).
+    FileHandle _fhandle;
+    offset_t _offset;
+    zsize_t _size;
+};
+
+class MultiPartFileReader : public Reader {
+  public:
+    MultiPartFileReader(std::shared_ptr<const FileCompound> source);
+    ~MultiPartFileReader() {};
+
+    zsize_t size() const { return _size; };
+    offset_t offset() const { return _offset; };
+
+    char read(offset_t offset) const;
+    void read(char* dest, offset_t offset, zsize_t size) const;
+    const Buffer get_buffer(offset_t offset, zsize_t size) const;
+
+    std::unique_ptr<const Reader> sub_reader(offset_t offset, zsize_t size) const;
 
   private:
-    FileReader(std::shared_ptr<const FileCompound> source, offset_t offset);
-    FileReader(std::shared_ptr<const FileCompound> source, offset_t offset, zsize_t size);
+    MultiPartFileReader(std::shared_ptr<const FileCompound> source, offset_t offset, zsize_t size);
 
     std::shared_ptr<const FileCompound> source;
     offset_t _offset;
