@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2017-2020 Mattieu Gautier <mgautier@kymeria.fr>
  * Copyright (C) 2008 Tommi Maekitalo
  *
  * This program is free software; you can redistribute it and/or
@@ -17,7 +18,7 @@
  *
  */
 
-#include <zim/fileheader.h>
+#include "fileheader.h"
 #include <zim/error.h>
 #include <iostream>
 #include <algorithm>
@@ -30,8 +31,7 @@
 # include "io.h"
 #else
 # include "unistd.h"
-# define _write(fd, addr, size) if(::write((fd), (addr), (size)) != (ssize_t)(size)) \
-{throw std::runtime_error("Error writing");}
+# define _write(fd, addr, size) ::write((fd), (addr), (size))
 #endif
 
 log_define("zim.file.header")
@@ -39,9 +39,9 @@ log_define("zim.file.header")
 namespace zim
 {
   const uint32_t Fileheader::zimMagic = 0x044d495a; // ="ZIM^d"
-  const uint16_t Fileheader::zimClassicMajorVersion = 5;
-  const uint16_t Fileheader::zimExtendedMajorVersion = 6;
-  const uint16_t Fileheader::zimMinorVersion = 0;
+  const uint16_t Fileheader::zimOldMajorVersion = 5;
+  const uint16_t Fileheader::zimMajorVersion = 6;
+  const uint16_t Fileheader::zimMinorVersion = 1;
   const offset_type Fileheader::size = 80; // This is also mimeListPos (so an offset)
 
   void Fileheader::write(int out_fd) const
@@ -61,7 +61,13 @@ namespace zim
     toLittleEndian(getLayoutPage(), header + 68);
     toLittleEndian(getChecksumPos(), header + 72);
 
-    _write(out_fd, header, Fileheader::size);
+    auto ret = _write(out_fd, header, Fileheader::size);
+    if (ret != Fileheader::size) {
+      std::cerr << "Error Writing" << std::endl;
+      std::cerr << "Ret is " << ret << std::endl;
+      perror("Error writing");
+      throw std::runtime_error("Error writing");
+    }
   }
 
   void Fileheader::read(const Reader& reader)
@@ -77,7 +83,7 @@ namespace zim
     }
 
     uint16_t major_version = seqReader.read<uint16_t>();
-    if (major_version != zimClassicMajorVersion && major_version != zimExtendedMajorVersion)
+    if (major_version != zimOldMajorVersion && major_version != zimMajorVersion)
     {
       log_error("invalid zimfile major version " << major_version << " found - "
           << Fileheader::zimMajorVersion << " expected");
