@@ -30,6 +30,7 @@
 #include <errno.h>
 #include <cstring>
 #include <fstream>
+#include <numeric>
 #include "config.h"
 #include "log.h"
 #include "envvalue.h"
@@ -80,6 +81,83 @@ makeFileReader(std::shared_ptr<const FileCompound> zimFile, offset_t offset, zsi
   }
 }
 
+// Consider a set of integer-numbered objects with their object-ids spanning a
+// contiguous range [a, b).
+// Each object is also labelled with an integer group id. The group-ids too
+// form a contiguous (or dense enough) set.
+// The Grouping class allows to re-arrange the stream of such objects fed
+// to it in the object-id order, returning a table of object-ids in the group-id
+// order (where the order of the objects within the same group is preserved).
+//
+template<class ObjectId, class GroupId>
+class Grouping
+{
+public: // types
+  typedef std::vector<ObjectId> GroupedObjectIds;
+
+public: // functions
+  explicit Grouping(ObjectId objectIdBegin, ObjectId objectIdEnd)
+    : firstObjectId_(objectIdBegin)
+    , minGroupId_(std::numeric_limits<GroupId>::max())
+    , maxGroupId_(std::numeric_limits<GroupId>::min())
+  {
+    groupIds_.reserve(objectIdEnd - objectIdBegin);
+  }
+
+  // i'th call of add() is assumed to refer to the object
+  // with id (firstObjectId_+i)
+  void add(GroupId groupId)
+  {
+    groupIds_.push_back(groupId);
+    minGroupId_ = std::min(minGroupId_, groupId);
+    maxGroupId_ = std::max(maxGroupId_, groupId);
+  }
+
+  GroupedObjectIds getGroupedObjectIds()
+  {
+    GroupedObjectIds result;
+    if ( !groupIds_.empty() ) {
+      // nextObjectSeat[g - minGroupId_] tells where the next object
+      // with group-id g must be placed (seated) in the result
+      std::vector<size_t> nextObjectSeat = getGroupBoundaries();
+
+      result.resize(groupIds_.size());
+      for ( size_t i = 0; i < groupIds_.size(); ++i ) {
+        const GroupId g = groupIds_[i];
+        // This statement has an important side-effect  vv
+        const auto pos = nextObjectSeat[g - minGroupId_]++;
+        result[pos] = firstObjectId_ + i;
+      }
+      GroupIds().swap(groupIds_);
+    }
+    return result;
+  }
+
+private: // functions
+  std::vector<size_t> getGroupBoundaries() const
+  {
+    std::vector<size_t> groupIdCounts(maxGroupId_ - minGroupId_ + 1, 0);
+    for ( const auto groupId : groupIds_ ) {
+      ++groupIdCounts[groupId - minGroupId_];
+    }
+
+    std::vector<size_t> groupBoundaries(1, 0);
+    std::partial_sum(groupIdCounts.begin(), groupIdCounts.end(),
+                     std::back_inserter(groupBoundaries)
+    );
+    return groupBoundaries;
+  }
+
+private: // types
+  typedef std::vector<GroupId> GroupIds;
+
+private: // data
+  const ObjectId firstObjectId_;
+  GroupIds groupIds_;
+  GroupId minGroupId_;
+  GroupId maxGroupId_;
+};
+
 } //unnamed namespace
 
   //////////////////////////////////////////////////////////////////////
@@ -192,11 +270,19 @@ makeFileReader(std::shared_ptr<const FileCompound> zimFile, offset_t offset, zsi
 
   FileImpl::DirentLookup& FileImpl::direntLookup() const
   {
-    std::call_once(m_direntLookupOnceFlag, [this]{
-
-      const auto cacheSize = envValue("ZIM_DIRENTLOOKUPCACHE", DIRENT_LOOKUP_CACHE_SIZE);
-      m_direntLookup.reset(new DirentLookup(mp_urlDirentAccessor.get(), cacheSize));
-    });
+    // Not using std::call_once because it is buggy.
+    // 1. It doesn't play well with musl libc - an exception thrown by the
+    //    callable results in SIGABRT even if there is a handler for it higher
+    //    in the call stack.
+    // 2. With `glibc` an exceptional execution of `std::call_once` doesn't
+    //    unlock the mutex associated with the `std::once_flag` object.
+    if ( !m_direntLookup ) {
+      std::lock_guard<std::mutex> lock(m_direntLookupCreationMutex);
+      if ( !m_direntLookup ) {
+        const auto cacheSize = envValue("ZIM_DIRENTLOOKUPCACHE", DIRENT_LOOKUP_CACHE_SIZE);
+        m_direntLookup.reset(new DirentLookup(mp_urlDirentAccessor.get(), cacheSize));
+      }
+    }
     return *m_direntLookup;
   }
 
@@ -338,33 +424,41 @@ makeFileReader(std::shared_ptr<const FileCompound> zimFile, offset_t offset, zsi
     return entry_index_t(mp_titleDirentAccessor->getDirentCount().v);
   }
 
+  void FileImpl::prepareArticleListByCluster() const
+  {
+    const auto endIdx = getEndUserEntry().v;
+    const auto startIdx = getStartUserEntry().v;
+    Grouping<entry_index_type, cluster_index_type> g(startIdx, endIdx);
+    for(auto i = startIdx; i < endIdx; i++)
+    {
+      // This is the offset of the dirent in the zimFile
+      auto indexOffset = mp_urlDirentAccessor->getOffset(entry_index_t(i));
+      // Get the mimeType of the dirent (offset 0) to know the type of the dirent
+      uint16_t mimeType = zimReader->read_uint<uint16_t>(indexOffset);
+      if (mimeType==Dirent::redirectMimeType || mimeType==Dirent::linktargetMimeType || mimeType == Dirent::deletedMimeType) {
+        g.add(0);
+      } else {
+        // If it is a classic article, get the clusterNumber (at offset 8)
+        auto clusterNumber = zimReader->read_uint<zim::cluster_index_type>(indexOffset+offset_t(8));
+        g.add(clusterNumber);
+      }
+    }
+    m_articleListByCluster = g.getGroupedObjectIds();
+  }
+
   entry_index_t FileImpl::getIndexByClusterOrder(entry_index_t idx) const
   {
-      std::call_once(orderOnceFlag, [this]
-      {
-          articleListByCluster.reserve(getUserEntryCount().v);
-
-          auto endIdx = getEndUserEntry().v;
-          for(auto i = getStartUserEntry().v; i < endIdx; i++)
-          {
-              // This is the offset of the dirent in the zimFile
-              auto indexOffset = mp_urlDirentAccessor->getOffset(entry_index_t(i));
-              // Get the mimeType of the dirent (offset 0) to know the type of the dirent
-              uint16_t mimeType = zimReader->read_uint<uint16_t>(indexOffset);
-              if (mimeType==Dirent::redirectMimeType || mimeType==Dirent::linktargetMimeType || mimeType == Dirent::deletedMimeType) {
-                articleListByCluster.push_back(std::make_pair(0, i));
-              } else {
-                // If it is a classic article, get the clusterNumber (at offset 8)
-                auto clusterNumber = zimReader->read_uint<zim::cluster_index_type>(indexOffset+offset_t(8));
-                articleListByCluster.push_back(std::make_pair(clusterNumber, i));
-              }
-          }
-          std::sort(articleListByCluster.begin(), articleListByCluster.end());
-      });
-
-      if (idx.v >= articleListByCluster.size())
-        throw std::out_of_range("entry index out of range");
-      return entry_index_t(articleListByCluster[idx.v].second);
+    // Not using std::call_once because it is buggy. See the comment
+    // in FileImpl::direntLookup().
+    if ( m_articleListByCluster.empty() ) {
+      std::lock_guard<std::mutex> lock(m_articleListByClusterMutex);
+      if ( m_articleListByCluster.empty() ) {
+        prepareArticleListByCluster();
+      }
+    }
+    if (idx.v >= m_articleListByCluster.size())
+      throw std::out_of_range("entry index out of range");
+    return entry_index_t(m_articleListByCluster[idx.v]);
   }
 
   FileImpl::ClusterHandle FileImpl::readCluster(cluster_index_t idx)
@@ -388,7 +482,7 @@ makeFileReader(std::shared_ptr<const FileCompound> zimFile, offset_t offset, zsi
     // we are still consumming address space. On 32bits this start to be a rare
     // ressource when we reserved 128Mb at once.
     // So we drop the cluster from the cache to avoid future memory allocation error.
-    if (cluster->getCompression() == Compression::Zstd) {
+    if (cluster->getCompression() == Cluster::Compression::Zstd) {
       // ZSTD compression starts to be used on version 5.0 of zim format.
       // Recently after, we switch to 5.1 and itegrate the fix in zstd creation.
       // 5.0 is not a perfect way to detect faulty zim file (it will generate false
