@@ -128,12 +128,6 @@ void Cluster::compress()
 {
   auto comp = getCompression();
   switch(comp) {
-    case Compression::Lzma:
-      {
-        _compress<LZMA_INFO>();
-        break;
-      }
-
     case Compression::Zstd:
       {
         _compress<ZSTD_INFO>();
@@ -198,7 +192,6 @@ void Cluster::write(int out_fd) const
       break;
     }
 
-    case Compression::Lzma:
     case Compression::Zstd:
       {
         log_debug("compress data");
@@ -250,7 +243,12 @@ void Cluster::write_data(writer_t writer) const
       size += blob.size();
       writer(blob);
     }
-    ASSERT(size, ==, provider->getSize());
+    if (size != provider->getSize()) {
+      std::stringstream ss;
+      ss << "Declared provider's size (" << provider->getSize() << ")";
+      ss << " is not equal to total size returned by feed() calls (" << size << ").";
+      throw IncoherentImplementationError(ss.str());
+    }
   }
 }
 
